Struct TrancheFlags
pub struct TrancheFlags(/* private fields */);wayland and Linux only.Implementations
impl TrancheFlags
impl TrancheFlags
pub const Scanout: TrancheFlags
pub const Scanout: TrancheFlags
direct scan-out tranche
impl TrancheFlags
impl TrancheFlags
pub const fn empty() -> TrancheFlags
pub const fn empty() -> TrancheFlags
Get a flags value with all bits unset.
pub const fn all() -> TrancheFlags
pub const fn all() -> TrancheFlags
Get a flags value with all known bits set.
pub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
pub const fn from_bits(bits: u32) -> Option<TrancheFlags>
pub const fn from_bits(bits: u32) -> Option<TrancheFlags>
Convert from a bits value.
This method will return None if any unknown bits are set.
pub const fn from_bits_truncate(bits: u32) -> TrancheFlags
pub const fn from_bits_truncate(bits: u32) -> TrancheFlags
Convert from a bits value, unsetting any unknown bits.
pub const fn from_bits_retain(bits: u32) -> TrancheFlags
pub const fn from_bits_retain(bits: u32) -> TrancheFlags
Convert from a bits value exactly.
pub fn from_name(name: &str) -> Option<TrancheFlags>
pub fn from_name(name: &str) -> Option<TrancheFlags>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
pub const fn intersects(&self, other: TrancheFlags) -> bool
pub const fn intersects(&self, other: TrancheFlags) -> bool
Whether any set bits in other are also set in self.
pub const fn contains(&self, other: TrancheFlags) -> bool
pub const fn contains(&self, other: TrancheFlags) -> bool
Whether all set bits in other are also set in self.
pub fn insert(&mut self, other: TrancheFlags)
pub fn insert(&mut self, other: TrancheFlags)
The bitwise or (|) of the bits in self and other.
pub fn remove(&mut self, other: TrancheFlags)
pub fn remove(&mut self, other: TrancheFlags)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
pub fn toggle(&mut self, other: TrancheFlags)
pub fn toggle(&mut self, other: TrancheFlags)
The bitwise exclusive-or (^) of the bits in self and other.
pub fn set(&mut self, other: TrancheFlags, value: bool)
pub fn set(&mut self, other: TrancheFlags, value: bool)
Call insert when value is true or remove when value is false.
pub const fn intersection(self, other: TrancheFlags) -> TrancheFlags
pub const fn intersection(self, other: TrancheFlags) -> TrancheFlags
The bitwise and (&) of the bits in self and other.
pub const fn union(self, other: TrancheFlags) -> TrancheFlags
pub const fn union(self, other: TrancheFlags) -> TrancheFlags
The bitwise or (|) of the bits in self and other.
pub const fn difference(self, other: TrancheFlags) -> TrancheFlags
pub const fn difference(self, other: TrancheFlags) -> TrancheFlags
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
pub const fn symmetric_difference(self, other: TrancheFlags) -> TrancheFlags
pub const fn symmetric_difference(self, other: TrancheFlags) -> TrancheFlags
The bitwise exclusive-or (^) of the bits in self and other.
pub const fn complement(self) -> TrancheFlags
pub const fn complement(self) -> TrancheFlags
The bitwise negation (!) of the bits in self, truncating the result.
impl TrancheFlags
impl TrancheFlags
pub const fn iter(&self) -> Iter<TrancheFlags>
pub const fn iter(&self) -> Iter<TrancheFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
pub const fn iter_names(&self) -> IterNames<TrancheFlags>
pub const fn iter_names(&self) -> IterNames<TrancheFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.